@@ -13,13 +13,22 @@
 #include <Rinternals.h>
 
 #define ME(matrix,row,col) (((matrix)->entries)[(col) * ((matrix)->nr) + (row)])
+#define ME3(matrix3,dim1,row,col) (((matrix3)->entries)[(dim1)*(((matrix3)->nr)*((matrix3)->nc))+(col)*((matrix3)->nr)+(row)])
 #define VE(vector,index) (((vector)->entries)[(index)])
 #define oops(s) {error((s));}
 #define max(a,b) ( ((a) > (b)) ? (a) : (b) )
 #define min(a,b) ( ((a) > (b)) ? (b) : (a) )
 #define malloc_mat(NR, NC, M) { (M) = Calloc(1,matrix); ((M)->nr) = (NR); ((M)->nc) = (NC); ((M)->entries) = Calloc(((NR)*(NC)) , double);}
+#define malloc_mat3(DIM,NR, NC, M3) {(M3) = Calloc(1,matrix); ((M3)->dim)=(DIM); ((M3)->nr) = (NR); ((M3)->nc) = (NC); ((M3)->entries) = Calloc(((DIM)*(NR)*(NC)) , double);}
 #define malloc_vec(L, V) { (V) = Calloc(1,vector); ((V)->length) = (L); ((V)->entries) = Calloc((L), double);}
 
+typedef struct{
+  int dim;
+  int nr;
+  int nc;
+  double *entries;
+} matrix3;
+
 typedef struct{
   int nr;
   int nc;
@@ -38,6 +47,8 @@ typedef struct{
 
 /* void malloc_mat(int *nrow, int *ncol, matrix *M); */
 
+void free_mat3(matrix3 *M);
+
 void free_mat(matrix *M);
 
 /* void malloc_vec(int *length, vector *V); */
@@ -156,6 +167,9 @@ void invertS(matrix *A, matrix *AI,int silent);
 void invertUnsafe(matrix *A, matrix *AI);
 void invertUnsafeS(matrix *A, matrix *AI,int silent);
 
+void cholesky(matrix *A, matrix *AI);
+void choleskyunsafe(matrix *A, matrix *AI);
+
 void MxA(matrix *M, matrix *A, matrix *Mout);
 
 void R_CheckUserInterrupt(void);
@@ -188,6 +202,19 @@ void replace_col(matrix *M, int col_to_set, vector *v);
 
 vector *extract_col(matrix *M, int col_to_get, vector *v);
 
+void Cpred(double *cum,int *nx,int *px,double *xval,int *nxval,double *pred); 
+
+void sindex(int *index, double *jump, double *eval, int *njump, int *neval,int *strict);
+
+void nclusters(int *npers,int *clusters, int *nclust, int *mclust);
+
+void clusterindex(int *clusters, int *nclust,int *npers,int *idclust, int *clustsize,
+	          int *mednum,int *num,int *firstclustid); 
+
+
+void clusterindexdata(int *clusters,int *nclust,int *npers,int *idclust,int *clustsize,int *mednum,
+		int *num,double *data, int *p,double *nydata); 
+ 
 void comptest(double *times,int *Ntimes,int *px,double *cu,double *vcu,
 	      double *vcudif,int *antsim,double *test,double *testOBS,
 	      double *Ut,double *simUt,matrix **W4t,int *weighted,int *antpers); 
@@ -201,7 +228,6 @@ void comptestfunc(double *times,int *Ntimes,int *px,double *cu,double *vcu,
 		  double *Ut,double *simUt,matrix **W4t,int *weighted,int *antpers,
 		  double *gamma,int *line,double *timepowtest); 
 
-
 void itfitsemi(double *times,int *Ntimes,double *x,int *delta,int *cause,double *KMc,
 	       double *z,int *antpers,int *px,int *Nit,double *score,double *hess,
 	       double *est,double *var,int *sim,int *antsim,double *test,
@@ -211,10 +237,22 @@ void itfitsemi(double *times,int *Ntimes,double *x,int *delta,int *cause,double
 	       double *timepow,int *clusters,int *antclust,double *timepowtest,int *silent,double *convc,
 	       double *weight,double *entry,double *trunkp,int *estimator,int *fixgamma ,int *stratum,
                int *ordertime,int *conservative);
-/* ,double *ssf); */
+/* , double *ssf); */
+
 
 void LevenbergMarquardt(matrix *S,matrix *SI,vector *U,vector *delta,double *lm,double *step); 
-void readXt2(int *antpers,int *nx,int *p,double *designX,double *start,double *stop,int *status,int pers,matrix *X,double time);
-void readXt(int *antpers,int *nx,int *p,double *designX,double *start,double *stop,int *status,int pers,matrix *X,double time,int *clusters,int *cluster,int *id) ;
-void readXZt(int *antpers,int *nx,int *px,double *designX,int *pg,double *designG,double *start,double *stop,int *status,int pers,matrix *X,matrix *WX,matrix *Z,matrix *WZ,double time,int *clusters,int *cluster,int *ls,int stat,int l,int *id,int s,int medw);
-void readXZtsimple(int *antpers,int *nx,int *px,double *designX,int *pg,double *designG,double *start,double *stop,int *status,int pers,matrix *X,matrix *Z,double time,int s,int *id); 
+ 
+void readXt2(int *antpers,int *nx,int *p,double *designX,
+             double *start,double *stop,int *status,int pers,matrix *X,double time);
+
+void readXt(int *antpers,int *nx,int *p,double *designX,double *start,double *stop,
+	int *status,int pers,matrix *X,double time,int *clusters,int *cluster,int *id) ;
+
+void readXZt(int *antpers,int *nx,int *px,double *designX,int *pg,double *designG,
+		double *start,double *stop,int *status,int pers,matrix *X,
+		matrix *WX,matrix *Z,matrix *WZ,double time,int *clusters,
+		int *cluster,int *ls,int stat,int l,int *id,int s,int medw);
+
+void readXZtsimple(int *antpers,int *nx,int *px,double *designX,int *pg,double *designG,
+		double *start,double *stop,int *status,int pers,matrix *X,
+	       	matrix *Z,double time, int s, int *id); 
